//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { useEffect, useState } from "react";
import { Elements, useStripe, useElements, PaymentElement } from "@stripe/react-stripe-js";
import { loadStripe } from "@stripe/stripe-js";
import { useSolution } from "primeobjects-helper-ui/build/cjs/hooks/solution";
import { isNonEmptyString } from "primeobjects-helper-util";
import ListLoadingSection from "../sections/list/loading";
import { callApi } from "../context/auth-call-api";
import { usePrimaryColorName } from "primeobjects-helper-ui/build/cjs/hooks/primary-color";
import { getApiEndpoint } from "../util";
import { ResizeDetectorDiv } from "primeobjects-ui-web-basic";
import { isNil } from "lodash";
// Make sure to call `loadStripe` outside of a component’s render to avoid
// recreating the `Stripe` object on every render.
// Publishable key
var stripePromise = loadStripe("pk_9xdrUeAVXvo55Dn0lcpCWcgZXvmCX");
export var Stripe = function (props) {
    var id = props.id, paymentMethod = props.paymentMethod, currency = props.currency, attributeName = props.attributeName;
    var solution = useSolution();
    var primaryColorName = usePrimaryColorName(solution);
    var _a = useState(undefined), clientSecret = _a[0], setClientSecret = _a[1];
    var _b = useState(false), loading = _b[0], setLoading = _b[1];
    var _c = useState(""), error = _c[0], setError = _c[1];
    var _d = useState(undefined), triggerSubmit = _d[0], setTriggerSubmit = _d[1];
    useEffect(function () {
        if (id) {
            setLoading(true);
            callApi(solution, getApiEndpoint(solution, "pay", "create-intent"), 
            //"http://localhost:3000/prod/create-intent", //`${solution.apis.pay}create-intent`,
            {
                id: id,
                attributeName: attributeName,
                currency: currency,
                paymentMethodTypes: paymentMethod
            }, "POST")
                .then(function (result) {
                if (!result.clientSecret) {
                    setError("Failed to create payment intention.");
                }
                else {
                    setClientSecret(result.clientSecret);
                }
            })
                .catch(function (error) {
                var _a, _b;
                console.error(error);
                setError("Failed to create payment intention. ".concat(((_a = error === null || error === void 0 ? void 0 : error.detail) === null || _a === void 0 ? void 0 : _a.reason) ? (_b = error === null || error === void 0 ? void 0 : error.detail) === null || _b === void 0 ? void 0 : _b.reason : ""));
            })
                .finally(function () {
                setLoading(false);
            });
        }
    }, [id]);
    var renderLoader = function () {
        if (!loading)
            return null;
        return (React.createElement(ListLoadingSection, { id: "stripe-section-loading", height: 60, count: 3, barHeight: 10, widthAdj: -30, style: { paddingLeft: 0, paddingRight: 0 } }));
    };
    var renderError = function () {
        if (!isNonEmptyString(error))
            return null;
        return React.createElement("div", { className: "w-full text-red-600" }, error);
    };
    var onSubmit = function () {
        setTriggerSubmit(Date.now());
    };
    var onResize = function (width, height) {
        console.log({ width: width, height: height });
    };
    return (React.createElement(ResizeDetectorDiv, { className: "w-full flex flex-col", onDetect: onResize },
        renderLoader(),
        renderError(),
        !loading && !isNonEmptyString(error) && clientSecret && (React.createElement(React.Fragment, null,
            React.createElement(Elements, { stripe: stripePromise, options: {
                    clientSecret: clientSecret,
                    appearance: {
                        theme: "stripe",
                        variables: {
                            focusBoxShadow: "none",
                            focusOutline: "none",
                            colorPrimary: "#333333",
                            colorBackground: "#ffffff",
                            colorText: "#333333",
                            colorDanger: "#df1b41",
                            spacingGridRow: "16px",
                            spacingGridColumn: "16px",
                            fontFamily: "-apple-system, BlinkMacSystemFont, Segoe UI, Roboto, Helvetica Neue, Arial, Noto Sans, sans-serif, Apple Color Emoji, Segoe UI Emoji, Segoe UI Symbol, Noto Color Emoji;",
                            spacingUnit: "2px",
                            borderRadius: "0px",
                            fontSizeBase: "14px"
                            // See all possible variables below
                        }
                    }
                } },
                React.createElement(StripeForm, __assign({}, props, { clientSecret: clientSecret, triggerSubmit: triggerSubmit }))),
            React.createElement("div", { className: "w-full mt-4" },
                React.createElement("div", { style: { maxWidth: 100 }, className: "flex rounded-md cursor-pointer h-6 px-2 py-4 shadow hover:shadow-lg text-white justify-center items-center leading-none bg-".concat(primaryColorName, "-500 hover:bg-").concat(primaryColorName, "-600"), onClick: onSubmit },
                    React.createElement("span", { className: "whitespace-nowrap text-white" }, "Pay Now")))))));
};
export var StripeForm = function (props) {
    var paymentMethod = props.paymentMethod, clientSecret = props.clientSecret;
    var stripe = useStripe();
    var elements = useElements();
    useEffect(function () {
        if (!isNil(props.triggerSubmit)) {
            onClickSubmit();
        }
    }, [props.triggerSubmit]);
    var onClickSubmit = function () {
        // We don't want to let default form submission happen here,
        // which would refresh the page.
        if (!stripe || !elements) {
            // Stripe.js has not yet loaded.
            // Make sure to disable form submission until Stripe.js has loaded.
            return;
        }
        switch (paymentMethod) {
            case "wechat_pay": {
                stripe.confirmWechatPayPayment(clientSecret, {
                    payment_method_options: {
                        wechat_pay: {
                            client: "web"
                        }
                    }
                });
                break;
            }
            default: {
                stripe
                    .confirmPayment({
                    //`Elements` instance that was used to create the Payment Element
                    elements: elements,
                    redirect: "if_required",
                    confirmParams: {
                        return_url: props.returnUrl
                    }
                })
                    .then(function (result) {
                    if (result.error) {
                        // Show error to your customer (for example, payment details incomplete)
                        console.log(result.error.message);
                    }
                    else {
                        // Your customer will be redirected to your `return_url`. For some payment
                        // methods like iDEAL, your customer will be redirected to an intermediate
                        // site first to authorize the payment, then redirected to the `return_url`.
                    }
                });
            }
        }
    };
    return (React.createElement("form", null,
        React.createElement(PaymentElement, null)));
};
export default Stripe;
//# sourceMappingURL=stripe.js.map