//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
import React, { useState, useEffect } from "react";
import SearchSection from "../search";
import SVG from "primeobjects-ui-web-basic/build/cjs/controls/svg";
import { useEnvStore } from "primeobjects-ui-web-store";
import { observer } from "mobx-react-lite";
import { COLORS, doNothing, isNonEmptyString, newGuid } from "primeobjects-helper-util";
import Button from "../../controls/action-button";
import { usePrimaryColor } from "primeobjects-helper-ui";
import Dropdown from "../../controls/antd/dropdown";
import Menu from "../../controls/antd/menu";
import Popover from "../../controls/antd/popover";
import { Parser } from "@json2csv/plainjs";
import { map, each } from "lodash";
import { getLocalStorage, setLocalStorage } from "primeobjects-ui-web-basic/build/cjs/util/local-storage";
export var ListHeaderSection = observer(function (props) {
    var _a, _b;
    var entity = props.entity, cancelSearch = props.cancelSearch, showTags = props.showTags, hideSearchService = props.hideSearchService, queryResult = props.queryResult;
    var envStore = useEnvStore();
    var envData = JSON.parse(envStore.data);
    var searching = (_a = envData === null || envData === void 0 ? void 0 : envData.search) === null || _a === void 0 ? void 0 : _a.doing;
    var primaryColor = usePrimaryColor();
    var createButtonText = props.createButtonText
        ? props.createButtonText
        : "New";
    var _c = useState(undefined), searchService = _c[0], setSearchService = _c[1];
    var hideCreateButton = entity.disableCreate == true ||
        props.hideCreateButton == true ||
        !props.onClickCreateButton;
    console.log({ AA: props.exportProps });
    var exportProps = (_b = props.exportProps) !== null && _b !== void 0 ? _b : [
        "id",
        "display",
        "stateCode",
        "statusCode",
        "createdOn|datetime",
        "modifiedOn|datetime",
        "organizationId",
        "solutionId"
    ];
    var _d = useState(false), openCategories = _d[0], setOpenCategories = _d[1];
    var query = queryResult === null || queryResult === void 0 ? void 0 : queryResult.query;
    var result = queryResult === null || queryResult === void 0 ? void 0 : queryResult.result;
    useEffect(function () {
        //check whether there is a local saved search service
        var localQueryService = getLocalStorage("query-service-".concat(query === null || query === void 0 ? void 0 : query.entityName));
        setSearchService(hideSearchService
            ? "hidden"
            : (query === null || query === void 0 ? void 0 : query.service) != "hidden" && localQueryService
                ? localQueryService
                : (query === null || query === void 0 ? void 0 : query.service)
                    ? query === null || query === void 0 ? void 0 : query.service
                    : "auto");
    }, [query]);
    var onSubmitSearch = function (keywords) {
        props.onSubmitSearch && props.onSubmitSearch(keywords);
    };
    var onRefresh = function () {
        props.onRefresh && props.onRefresh();
    };
    var getPropValue = function (record, name) {
        if (!name || !isNonEmptyString(name) || !record)
            return undefined;
        var layers = name.split(".");
        if (layers.length > 1) {
            var curName = layers.shift();
            if (curName) {
                var newRecord = record[curName];
                var newName = layers.join(".");
                return getPropValue(newRecord, newName);
            }
            else {
                return undefined;
            }
        }
        return record[name];
    };
    var onClickExport = function (all) {
        doNothing(all);
        try {
            if (result) {
                var parser = new Parser();
                var data = map(result === null || result === void 0 ? void 0 : result.data, function (r) {
                    var newR = {};
                    each(exportProps, function (fname) {
                        var nameType = fname.split("|");
                        var type = nameType.length > 1 ? nameType[1] : "";
                        var name = nameType[0];
                        switch (type) {
                            case "datetime": {
                                newR[fname] = new Date(getPropValue(r, name));
                                break;
                            }
                            default: {
                                newR[fname] = getPropValue(r, name);
                                break;
                            }
                        }
                        // if (
                        //     isNumber(v) &&
                        //     isDate(new Date(v)) &&
                        //     new Date(v).getTime() -
                        //         new Date("1971-1-1").getTime() >
                        //         0
                        // ) {
                        //     newR[fname] = new Date(v);
                        // } else {
                        //     newR[fname] = v;
                        // }
                    });
                    return newR;
                });
                var csv = parser.parse(data);
                var element = document.createElement("a");
                element.setAttribute("href", "data:text/plain;charset=utf-8," +
                    encodeURIComponent("".concat(csv)));
                element.setAttribute("download", "".concat(entity.entityName.toLowerCase()).concat(entity.entityType
                    ? "-".concat(entity.entityType.toLowerCase())
                    : "", "-").concat(Date.now(), ".csv"));
                element.style.display = "none";
                document.body.appendChild(element);
                element.click();
                document.body.removeChild(element);
            }
        }
        catch (err) {
            console.error(err);
        }
    };
    var onClickToggleTagsButton = function () {
        props.onClickToggleTagsButton && props.onClickToggleTagsButton();
    };
    var onClickFilterButton = function () { };
    var onClickCreateButton = function () {
        props.onClickCreateButton &&
            props.onClickCreateButton({
                id: newGuid(),
                entityName: entity.entityName,
                entityType: entity.entityType
            });
    };
    var onClickSearchService = function (service) {
        setLocalStorage("query-service-".concat(query === null || query === void 0 ? void 0 : query.entityName), service);
        setSearchService(service);
        props.onRefresh && props.onRefresh();
    };
    var renderCurrentSearchServiceName = function () {
        switch (searchService) {
            case "database": {
                return "Simple search engine";
            }
            case "elastic": {
                return "Full-text search engine";
            }
            default: {
                return "Auto search engine";
            }
        }
    };
    return (React.createElement("div", { className: "w-full flex flex-row py-4 items-center relative bg-white" },
        !props.hideEntityIcon && (React.createElement("div", { className: "flex ml-4" },
            React.createElement(SVG, { src: entity.icon, size: 32, color: COLORS.GRAY["900"] }))),
        props.onSubmitSearch && !props.hideSearch && (React.createElement(React.Fragment, null,
            React.createElement(SearchSection, { searching: searching, onSubmit: onSubmitSearch, placeholder: entity.searchInputPlaceholder
                    ? entity.searchInputPlaceholder
                    : "Search ".concat(entity.uiCollectionName, " ..."), wrapperStyle: searchService == "hidden"
                    ? { height: 32 }
                    : { height: 20 }, wrapperClassName: searchService == "hidden" ? "px-2" : "px-2 pt-2", inputClassName: "max-w-xs", cancelSearch: cancelSearch }),
            searchService != "hidden" && (React.createElement("div", { className: "absolute cursor-pointer", style: { top: 8, left: 56 } },
                React.createElement("div", { style: { width: 150 } },
                    React.createElement(Dropdown, { trigger: ["click"], placement: "top", overlay: React.createElement(Menu, null,
                            React.createElement(Menu.Item, { onClick: function () {
                                    return onClickSearchService("auto");
                                } }, "Auto search engine"),
                            React.createElement(Menu.Item, { onClick: function () {
                                    return onClickSearchService("database");
                                } }, "Simple search engine"),
                            React.createElement(Menu.Item, { onClick: function () {
                                    return onClickSearchService("elastic");
                                } }, "Full-text search engine")) },
                        React.createElement("div", { className: "w-full flex" },
                            React.createElement("div", { className: "text-xs" }, renderCurrentSearchServiceName()),
                            React.createElement(SVG, { style: { margin: 4 }, src: "/icons/platform/down.svg", size: 10, color: COLORS.GRAY["900"] })))))))),
        React.createElement("div", { className: "flex mr-4" },
            props.hideCategoriesButton != true &&
                props.renderCategories && (React.createElement(Popover, { placement: "bottomRight", open: openCategories, onOpenChange: function (newOpen) {
                    setOpenCategories(newOpen);
                }, trigger: "click", content: React.createElement("div", { style: { width: 350 } }, props.renderCategories(function () {
                    setOpenCategories(false);
                })) },
                React.createElement(Button, { id: "list-header-categories", iconSrc: "/icons/platform/categories.svg" }))),
            (exportProps === null || exportProps === void 0 ? void 0 : exportProps.length) > 0 && !props.hideExportButton && (React.createElement(Dropdown, { trigger: ["click"], overlay: React.createElement(Menu, null,
                    React.createElement(Menu.Item, { key: "export-current", className: "w-full", onClick: function () {
                            onClickExport(false);
                        } },
                        React.createElement("span", null, "Export current records")),
                    React.createElement(Menu.Item, { key: "export-all", className: "w-full", onClick: function () {
                            onClickExport(true);
                        } },
                        React.createElement("span", null, "Export all records"))), placement: "bottomLeft" },
                React.createElement(Button, { id: "list-header-export-csv", iconSrc: "/icons/platform/export-csv.svg" }))),
            props.onRefresh && (React.createElement(Button, { id: "list-header-refresh", onClick: onRefresh, iconSrc: "/icons/platform/refresh.svg" })),
            props.onClickToggleTagsButton && (React.createElement(Button, { id: "list-header-filter", onClick: onClickToggleTagsButton, iconSrc: "/icons/platform/tags.svg", tooltipText: "Toggle tags", iconColor: showTags ? primaryColor["600"] : undefined })),
            props.onClickFilterButton && (React.createElement(Button, { id: "list-header-filter", onClick: onClickFilterButton, iconSrc: "/icons/platform/filter.svg" })),
            !hideCreateButton && (React.createElement(Button, { id: "list-header-new", onClick: onClickCreateButton, wrapperClassName: "bg-green-500 hover:bg-green-600", text: createButtonText, textColor: COLORS.WHITE })))));
});
export default ListHeaderSection;
//# sourceMappingURL=header.js.map