//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { useEffect, useState } from "react";
import { map, filter, isNil } from "lodash";
import { isNonEmptyString, isObject } from "primeobjects-helper-util/build/cjs/core";
import { usePrimaryColor } from "primeobjects-helper-ui/build/cjs/hooks/primary-color";
import { useRouter } from "next/router";
import { useCurrentContext } from "../../context/use-current-context";
import SVG from "primeobjects-ui-web-basic/build/cjs/controls/svg";
import Tooltip from "../../controls/antd/tooltip";
import Me from "./me";
import { COLORS } from "primeobjects-helper-util/build/cjs/colors";
import { getCookie, setCookie } from "primeobjects-ui-web-basic/build/cjs/util/cookie";
import { getWindow, hasRole } from "primeobjects-helper-util";
import GradientDiv from "primeobjects-ui-web-basic/build/cjs/controls/gradient-div";
import Logo from "primeobjects-ui-web-basic/build/cjs/controls/logo";
import { useEnvStore } from "primeobjects-ui-web-store/build/cjs/stores/env";
import { getNavItem, NavSectionItem, checkNavRole } from "./item";
import { useSolution } from "primeobjects-helper-ui";
import { observer } from "mobx-react-lite/dist/index";
export var NavSection = observer(function (props) {
    var _a;
    var fixedSize = props.fixedSize, allowGuest = props.allowGuest;
    var solution = (_a = useSolution()) !== null && _a !== void 0 ? _a : props.solution;
    var _b = useState(""), navSize = _b[0], setNavSize = _b[1];
    var _c = useState(""), selectedItemId = _c[0], setSelectedItemId = _c[1];
    var copyright = solution.site.copyright;
    var year = new Date().getFullYear();
    var businessName = solution.site.businessName;
    var version = solution.app.version;
    var hidden = props.hidden == true;
    var context = useCurrentContext(solution, {
        componentName: "/sections/nav/index.tsx"
    });
    var envStore = useEnvStore();
    var user = context === null || context === void 0 ? void 0 : context.user;
    var isSolutionAdmin = hasRole(context, "SOLUTION-ADMIN");
    var primaryColor = usePrimaryColor(solution);
    var router = useRouter();
    var wrapperClassName = isNonEmptyString(props.wrapperClassName)
        ? props.wrapperClassName
        : "";
    var wrapperStyle = isObject(props.wrapperStyle) ? props.wrapperStyle : {};
    copyright = copyright.replace(/\[PH.YEAR\]/g, "".concat(year));
    copyright = copyright.replace(/\[PH.BUSINESSNAME\]/g, "".concat(businessName));
    var width = hidden ? 0 : navSize == "sm" ? 80 : 240;
    // const supportResize =
    //     !fixedSize && navSize != "sm" && props.supportResize == true;
    // const rgb: any = hexToRgb(COLORS.GRAY[50]);
    // const nameGradientColorRGB = rgb && { r: rgb?.r, g: rgb.g, b: rgb.b };
    useEffect(function () {
        updateNavSize((fixedSize !== null && fixedSize !== void 0 ? fixedSize : getCookie("nav-size") == "sm") ? "sm" : "lg");
    }, []);
    useEffect(function () {
        if (!fixedSize && envStore.width <= 768 && navSize != "sm") {
            updateNavSize("sm");
        }
        if (!fixedSize && envStore.width > 768 && navSize != "lg") {
            updateNavSize("lg");
        }
    }, [envStore.width]);
    useEffect(function () {
        var selectedItem = getNavItem(solution.app.navigation, user, allowGuest);
        if (selectedItem) {
            setSelectedItemId(selectedItem.id);
            // onClickItem(selectedItem);
            props.onClickItem && props.onClickItem(selectedItem);
        }
    }, [user]);
    var onClickMe = function () {
        props.onClickMe && props.onClickMe();
    };
    var onClickSolution = function () {
        props.onClickSolution && props.onClickSolution();
    };
    var onClickItem = function (item) {
        setSelectedItemId(item.id);
        if (isNonEmptyString(item.src)) {
            router.push(item.src, undefined, { shallow: true });
        }
    };
    var onClickToggleNavSize = function () {
        updateNavSize(navSize == "sm" ? "lg" : "sm", true);
    };
    var updateNavSize = function (size, manual) {
        var manualSize = getCookie("nav-size");
        if (!manual && manualSize == "sm") {
            //no auto resize
            setNavSize("sm");
            return props.onResize && props.onResize(80, "sm");
        }
        else {
            if (manual) {
                setCookie("nav-size", size);
            }
            setNavSize(size);
            props.onResize && props.onResize(size == "sm" ? 80 : 220, size);
        }
    };
    var onClickLogo = function () {
        if (props.onClickLogo) {
            return props.onClickLogo();
        }
        else {
            getWindow().open("/");
        }
    };
    var renderSection = function (title) {
        return (React.createElement(GradientDiv
        // gradientColorRGB={{ r: 248, g: 250, b: 252 }}
        , { 
            // gradientColorRGB={{ r: 248, g: 250, b: 252 }}
            className: "uppercase relative py-2 mt-4 text-xs text-gray-500 leading-none ".concat(navSize == "sm" ? "justify-center" : "px-4"), style: { minHeight: "2rem" } }, title));
    };
    var renderItems = function (items) {
        return filter(map(items, function (item, index) {
            if (!checkNavRole(item, user) || item.hidden == true) {
                return null;
            }
            switch (item.id) {
                case "platform": {
                    return renderPlatformInfo();
                }
                case "solution": {
                    return (isSolutionAdmin && (React.createElement(NavSectionItem, { key: index, item: {
                            id: "solution",
                            title: "Solution Settings",
                            icon: "/icons/platform/solution.svg",
                            src: ""
                        }, color: primaryColor, onClickItem: onClickSolution, navSize: navSize })));
                }
                case "me": {
                    return (React.createElement("div", { className: "p-3" },
                        React.createElement(Me, { showName: navSize != "sm", onClick: onClickMe, size: 30 })));
                }
                default: {
                    return (React.createElement(NavSectionItem, { key: index, item: item, color: primaryColor, selected: selectedItemId == item.id, onClickItem: onClickItem, navSize: navSize }));
                }
            }
        }), function (item) { return !isNil(item); });
    };
    var renderNavigation = function () {
        return map(solution.app.navigation, function (nav, index) {
            if (!checkNavRole(nav, user) || nav.hidden == true) {
                return null;
            }
            return (React.createElement(React.Fragment, { key: index },
                nav.title && renderSection(nav.title),
                renderItems(nav.items)));
        });
    };
    var renderPlatformInfo = function () {
        return (React.createElement("div", { className: "w-full px-2 py-1 flex flex-row items-center" },
            React.createElement("div", { className: "relative flex flex-row w-full p-3 rounded hover:shadow ".concat(navSize == "sm" ? "flex-row justify-center" : "flex-col") },
                React.createElement("div", { className: navSize == "sm" ? "" : "mr-4" },
                    React.createElement(Logo, { color: "black", onClick: onClickLogo, logoSrc: "/logo.svg", logoSize: 28, text: navSize != "sm" ? copyright : undefined, textStyle: {
                            fontSize: 11,
                            fontWeight: 500,
                            marginLeft: navSize == "sm" ? 0 : 5
                        } })),
                navSize != "sm" && (React.createElement(Tooltip, { title: "VER: ".concat(version), color: primaryColor["400"], placement: "right" },
                    React.createElement("div", { className: "cursor-pointer", style: {
                            position: "absolute",
                            right: 10,
                            top: 20
                        } },
                        React.createElement(SVG, { src: "/icons/platform/info.svg", size: 16, color: COLORS.GRAY["800"] })))))));
    };
    return (React.createElement("nav", { className: "relative flex flex-col overflow-hidden overflow-y-auto py-4 ".concat(wrapperClassName), style: __assign({ height: envStore.height - 65, width: width, minWidth: width }, wrapperStyle) },
        React.createElement("div", { className: "shadow cursor-pointer bg-white rounded-full sticky hover:shadow-lg", style: {
                left: 4,
                top: -12,
                marginTop: -12,
                width: 18,
                height: 18
            } },
            React.createElement(SVG, { onClick: onClickToggleNavSize, color: primaryColor["600"], src: navSize == "sm"
                    ? "/icons/platform/circled-right.svg"
                    : "/icons/platform/circled-left.svg", size: 18 })),
        renderNavigation()));
});
export default NavSection;
//# sourceMappingURL=index.js.map